@@ -3,8 +3,9 @@ use Mouse::Util qw(:meta); # enables strict and warnings
 use Scalar::Util;
 
 sub _generate_delegation{
-    my (undef, $attribute, $metaclass, $reader, $handle_name, $method_to_call) = @_;
+    my (undef, $attribute, $handle_name, $method_to_call) = @_;
 
+    my $reader = $attribute->get_read_method_ref();
     return sub {
         my $instance = shift;
         my $proxy    = $instance->$reader();
@@ -34,7 +35,7 @@ Mouse::Meta::Method::Delegation - A Mouse method generator for delegation method
 
 =head1 VERSION
 
-This document describes Mouse version 0.44
+This document describes Mouse version 0.45
 
 =head1 SEE ALSO
 
